@@ -30,6 +30,8 @@ def download_autograder_materials(url, save_path=None):
     file_name = os.environ["AUTOGRADER_REPO"]
     extracted_path = f"{save_path}/{file_name}-{branch}"
     storage_path = f"{save_path}/{file_name}"
+    if os.path.isfile(storage_path):
+        shutil.rmtree(storage_path)
     os.rename(extracted_path, storage_path)
     os.remove(download_path)
     return storage_path
@@ -116,6 +118,3 @@ async def grade_assignment(submission, sec='3', assignment='lab01', solutions_pa
         raise Exception(f'Grading timed out for {submission}')
     except Exception as e:
         raise e
-    finally:
-        if solutions_base_path is not None:
-            shutil.rmtree(solutions_base_path)
